@@ -1,12 +1,20 @@
+#   Copyright (c) 2020-2021 STiiiCK.
+#
+#   This source code is licensed under the GPLv3 license found in the
+#   LICENSE file in the root directory of this source tree.
+
 import uuid
 
 from django.db import models
 from django.conf import settings
 
-
 User = settings.AUTH_USER_MODEL
 Group = settings.GROUP_MODEL
 
+#
+# @author Omar Basem
+#
+
 class IdentityKey(models.Model):
     """
     A user has one IdentityKey created at registration time
@@ -106,7 +114,7 @@ class Party(models.Model):
     In the context of the Stick protocol, a "party" is one of three:
     1. A Group.
     2. A collection of groups and/or users
-    3. My profile
+    3. My profile (currentUser profile - which includes of the currentUser's connections)
 
     Every user should be connected with a Party object created at registration time. Whenever a user shares
     with a collection of groups and/or users that does not correspond to any existing Party, a new Party object should
