@@ -1,3 +1,8 @@
+#   Copyright (c) 2020-2021 STiiiCK.
+#
+#   This source code is licensed under the GPLv3 license found in the
+#   LICENSE file in the root directory of this source tree.
+
 import uuid
 
 from .models import IdentityKey, SignedPreKey, PreKey, EncryptingSenderKey, DecryptingSenderKey, Party
@@ -5,11 +10,14 @@ from django.db.models import Q
 from firebase_admin import db
 from django.conf import settings
 
+
 DEFAULT_APP = settings.DEFAULT_APP
 FIREBASE_REF = settings.FIREBASE_REF
 FIREBASE_REF_DEV = settings.FIREBASE_REF_DEV
 
-
+#
+# @author Omar Basem
+#
 
 class StickProtocol():
 
@@ -63,8 +71,6 @@ class StickProtocol():
         a boolean `isSticky` to know whether this bundle would be used to communicate a SenderKey or not. If it will be used to
         communicate a SenderKey, then the PreKey must be marked as used, otherwise the PreKey is deleted from the server.
         """
-        # id = request.GET.get("id")
-        # deviceId = int(request.GET.get("deviceId"))
         userId = data['userId']
         deviceId = data['deviceId']
         isSticky = data['isSticky']
@@ -101,12 +107,6 @@ class StickProtocol():
         Similar to the above method, but fetches PreKeyBundles of several users at once. This method allows a user to
         communicate their SenderKey to multiple members of a party at once.
         """
-        # You can either provide in the request a list of `users_id` or just a `group_id`.
-        # if "users_id" in data:
-        #     users_id = data["users_id"]
-        # else:
-        #     users_id = Group.objects.get(id=data["group_id"]).get_all_users_ids()
-
         bundles = {}
         # Make sure the current user is the first in the list. When creating DecryptingSenderKeys client-side to share
         # with other members, their must already be a corresponding EncryptingSenderKey.
@@ -223,8 +223,8 @@ class StickProtocol():
                 phone = self.User.objects.get(id=memberId).phone
             else:
                 phone = data['phone']
-            dev = data['dev']
-            firebase_ref = FIREBASE_REF_DEV if dev else FIREBASE_REF
+            isDev = data['isDev']
+            firebase_ref = FIREBASE_REF_DEV if isDev else FIREBASE_REF
             ref = db.reference('users/' + phone + '/pendingKeys/', DEFAULT_APP, firebase_ref)
             ref.update({stickId + '--' + str(user.id): user.phone})
         return {'authorized': authorized, 'senderKey': key}
@@ -235,7 +235,7 @@ class StickProtocol():
         """
         This method is used to fetch the standard session sender keys of a group.
         """
-        stickId = data['chatId']
+        stickId = data['stickId']
         keysToFetch = data['keysToFetch']
         if group not in user.groups.all():
             return {'authorized': False}
@@ -260,7 +260,7 @@ class StickProtocol():
         * connections_ids - a list of users ids
         * isSticky - boolean, indicates whether the user is intending to use a sticky session
         * isProfile - boolean, indicates whether the user is sharing to their profile (includes all their connections)
-        * partyId (optional) - boolean, the partyId of a user
+        * partyId (optional) - the partyId of a user
         """
         groups_ids = data['groups_ids']
         connections_ids = data['connections_ids']
@@ -276,7 +276,7 @@ class StickProtocol():
                     partyId = groups_ids[0]
                 else: # Using standard session
                     membersIds = self.Group.objects.get(id=groups_ids[0]).get_members_otids()
-                    partyId = data["chatId"]
+                    partyId = data["stickId"]
             else: # Sharing with a collection of groups and/or users
                 if len(groups_ids) > 0 and len(connections_ids) > 0:
                     party = Party.objects.filter(Q(groups=groups_ids) & Q(connections=connections_ids)).first()
@@ -363,7 +363,7 @@ class StickProtocol():
 
 
 
-    def get_stick_id(self, data, currentUser):
+    def get_active_stick_id(self, data, currentUser):
         """
         This method gets the active sticky session stickId associated with a particular partyId that already exists, and
         its current step.
@@ -428,7 +428,7 @@ class StickProtocol():
         """
         This method is used to upload the SenderKeys of a standard session.
         """
-        stickId = data['chatId']
+        stickId = data['stickId']
         keysToUpload = data['keysToUpload']
         for oneTimeId, senderKey in keysToUpload.items():
             DecryptingSenderKey.objects.create(key=senderKey, stickId=stickId, ofUser=user,
